@@ -1,7 +1,6 @@
 """Base abstract backend class."""
-import typing as t
-
 import abc
+import typing as t
 
 
 class ABCBackend(abc.ABC):
@@ -11,36 +10,36 @@ class ABCBackend(abc.ABC):
     @abc.abstractmethod
     def name(self):
         """Backend should have a name."""
-        pass
 
-    def __init__(self, client: t.Any = None, timeout: int = None, **client_options):
+    def __init__(self, client: t.Any = None, timeout: int = None, **_):
         """Initialize the backend."""
-        pass
 
     def __init_subclass__(cls, *args, **kwargs):
         """Register a backend."""
         super().__init_subclass__(*args, **kwargs)
-        BACKENDS[cls.name] = cls
+        BACKENDS[str(cls.name)] = cls
 
     class Error(Exception):
         """Client exception."""
 
-        pass
-
     async def startup(self):
         """Prepare the backend."""
-        pass
 
     async def shutdown(self):
         """Close the backend."""
-        pass
 
     @abc.abstractmethod
-    async def request(self, method: str, url: str, *, raise_for_status: bool = True,
-                      read_response_body: bool = True, parse_response_body: bool = True,
-                      **options):
+    async def request(
+        self,
+        method: str,
+        url: str,
+        *,
+        raise_for_status: bool = True,
+        read_response_body: bool = True,
+        parse_response_body: bool = True,
+        **options
+    ):
         """Do http request with the backend."""
-        pass
 
 
 BACKENDS: t.Dict[str, t.Type[ABCBackend]] = {}
@@ -48,12 +47,14 @@ BACKENDS: t.Dict[str, t.Type[ABCBackend]] = {}
 
 try:
     from ._httpx import BackendHTTPX
+    assert BackendHTTPX
 
 except ImportError:
     pass
 
 try:
     from ._aiohttp import BackendAIOHTTP
+    assert BackendAIOHTTP
 
 except ImportError:
     pass
