@@ -11,8 +11,11 @@ class BackendHTTPX(ABCBackend):
 
     Error = httpx.HTTPError
 
-    def __init__(self, client: httpx.AsyncClient = None, **options):
+    def __init__(self, client: httpx.AsyncClient = None, uds: str = None, **options):
         """Initialize HTTPX Client."""
+        if uds:
+            options['transport'] = httpx.AsyncHTTPTransport(uds=uds)
+
         self.client = client or httpx.AsyncClient(**options)
 
     async def shutdown(self):
@@ -23,8 +26,8 @@ class BackendHTTPX(ABCBackend):
                       read_response_body: bool = True, parse_response_body: bool = True,
                       **options) -> httpx.Response:
         """Make a request."""
-        async with self.client.stream(method, url, **options) as response:
-
+        client = self.client
+        async with client.stream(method, url, **options) as response:
             if raise_for_status:
                 try:
                     response.raise_for_status()
@@ -41,7 +44,7 @@ class BackendHTTPX(ABCBackend):
 
             return response
 
-    def parse_response(self, response: httpx.Response, body: t.Any) -> t.Any:
+    def parse_response(self, response: httpx.Response, body: bytes) -> t.Any:
         """Parse body for given response by content-type.
 
         :returns: parsed body
@@ -50,4 +53,4 @@ class BackendHTTPX(ABCBackend):
         if ct.startswith('application/json'):
             return response.json()
 
-        return body.decode(response.encoding)
+        return body.decode(response.encoding or 'utf-8')
